from celery import shared_task
from django.conf import settings
from shiftregister.app.sipgate.history import list_incoming_sms
from .models import IncomingMessage
import sentry_sdk


@shared_task
def receive_messages():
    if not settings.SIPGATE_INCOMING_TOKEN or not settings.SIPGATE_INCOMING_TOKEN_ID:
        return

    try:
        from_dt = IncomingMessage.objects.latest().created_at
    except IncomingMessage.DoesNotExist:
        from_dt = None

    try:
        for sms in list_incoming_sms(from_dt):
            IncomingMessage(
                id=sms.id,
                sender=sms.sender,
                content=sms.content,
                created_at=sms.created_at,
            ).save()
    except Exception as e:
        sentry_sdk.capture_exception(e)
